@@ -17,8 +17,7 @@ if not sys.platform == 'darwin':
 # See issue 3332
 try:
     from OpenGL import GL
-except ImportError:
-    # pyopengl is not present when installed using conda
+except:
     pass
 
 # Local imports
